Index: ui/display/chromeos/test/action_logger_util.h |
diff --git a/ui/display/chromeos/test/action_logger_util.h b/ui/display/chromeos/test/action_logger_util.h |
index 2a90809cb59f9cc2f9e95d10fe1d9ab68ecf2358..06be848cfa4c2cf720c070dba09674f94a6c68ab 100644 |
--- a/ui/display/chromeos/test/action_logger_util.h |
+++ b/ui/display/chromeos/test/action_logger_util.h |
@@ -66,9 +66,13 @@ std::string GetFramebufferAction(const gfx::Size& size, |
std::string GetSetHDCPStateAction(const DisplaySnapshot& output, |
HDCPState state); |
-// Returns a string describing a TestNativeDisplayDelegate::SetGammaRamp() call; |
-std::string SetGammaRampAction(const ui::DisplaySnapshot& output, |
- const std::vector<GammaRampRGBEntry>& lut); |
+// Returns a string describing a TestNativeDisplayDelegate::SetColorCorrection() |
+// call; |
+std::string SetColorCorrectionAction( |
+ const ui::DisplaySnapshot& output, |
+ const std::vector<GammaRampRGBEntry>& degamma_lut, |
+ const std::vector<GammaRampRGBEntry>& gamma_lut, |
+ const std::vector<float>& correction_matrix); |
// Joins a sequence of strings describing actions (e.g. kScreenDim) such |
// that they can be compared against a string returned by |
// ActionLogger::GetActionsAndClear(). The list of actions must be |